@@ -105,7 +105,6 @@ arv_gc_register_node_post_new_child (ArvDomNode *self, ArvDomNode *child)
 				node->endianess = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_SIGN:
-				/* TODO */
 				node->sign = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_LSB:
@@ -347,7 +346,7 @@ _get_cachable (ArvGcRegisterNode *gc_register_node, GError **error)
 
 /* Set default to read only 32 bits little endian integer register */
 
-static ArvGcCachable
+static guint
 _get_endianess (ArvGcRegisterNode *gc_register_node, GError **error)
 {
 	GError *local_error = NULL;
@@ -369,6 +368,30 @@ _get_endianess (ArvGcRegisterNode *gc_register_node, GError **error)
 	return G_LITTLE_ENDIAN;
 }
 
+static ArvGcSignedness
+_get_signedness (ArvGcRegisterNode *gc_register_node, GError **error)
+{
+	GError *local_error = NULL;
+	const char *sign;
+
+	if (gc_register_node->sign == NULL)
+		return gc_register_node->type == ARV_GC_REGISTER_NODE_TYPE_REGISTER ?
+			ARV_GC_SIGNEDNESS_SIGNED :
+			ARV_GC_SIGNEDNESS_UNSIGNED;
+
+	sign = arv_gc_property_node_get_string (gc_register_node->sign, &local_error);
+
+	if (local_error != NULL) {
+		g_propagate_error (error, local_error);
+		return ARV_GC_SIGNEDNESS_SIGNED;
+	}
+
+	if (g_strcmp0 (sign, "Unsigned") == 0)
+		return ARV_GC_SIGNEDNESS_UNSIGNED;
+
+	return ARV_GC_SIGNEDNESS_SIGNED;
+}
+
 static gint64
 _get_lsb (ArvGcRegisterNode *gc_register_node, GError **error)
 {
@@ -392,7 +415,7 @@ _read_cache (ArvGcRegisterNode *gc_register_node, GError **error)
 {
 	GError *local_error = NULL;
 	ArvGcNode *port;
-	gboolean cachable;
+	ArvGcCachable cachable;
 	gint64 address;
 
 	if (gc_register_node->is_cache_valid == TRUE) {
@@ -446,7 +469,7 @@ _write_cache (ArvGcRegisterNode *gc_register_node, GError **error)
 {
 	GError *local_error = NULL;
 	gint64 address;
-	gboolean cachable;
+	ArvGcCachable cachable;
 	ArvGcNode *port;
 
 	arv_gc_feature_node_inc_modification_count (ARV_GC_FEATURE_NODE (gc_register_node));
@@ -677,7 +700,9 @@ arv_gc_register_node_register_interface_init (ArvGcRegisterInterface *interface)
 /* ArvGcInteger interface implementation */
 
 static gint64
-_get_integer_value (ArvGcRegisterNode *gc_register_node, guint register_lsb, guint register_msb, GError **error)
+_get_integer_value (ArvGcRegisterNode *gc_register_node,
+		    guint register_lsb, guint register_msb, ArvGcSignedness signedness,
+		    GError **error)
 {
 	GError *local_error = NULL;
 	gint64 value;
@@ -725,7 +750,20 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node, guint register_lsb, gui
 
 		value = (value & mask) >> lsb;
 
+		if (msb-lsb < 63 &&
+		    (value & (((guint64) 1) << (msb - lsb))) != 0 &&
+		    signedness == ARV_GC_SIGNEDNESS_SIGNED) {
+			value |= G_MAXUINT64 ^ (mask >> lsb);
+		}
+
 		arv_log_genicam ("[GcRegisterNode::_get_integer_value] mask  = 0x%08Lx", mask);
+	} else {
+		unsigned length = _get_length (gc_register_node, NULL);
+
+		if (length < 8 &&
+		    ((value & (((guint64) 1) << (length * 8 - 1))) != 0) &&
+		    signedness == ARV_GC_SIGNEDNESS_SIGNED)
+			value |= G_MAXUINT64 ^ ((((guint64) 1) << (length * 8)) - 1);
 	}
 
 	arv_log_genicam ("[GcRegisterNode::_get_integer_value] address = 0x%Lx, value = 0x%Lx",
@@ -735,12 +773,14 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node, guint register_lsb, gui
 }
 
 gint64
-arv_gc_register_node_get_masked_integer_value (ArvGcRegisterNode *gc_register_node, guint lsb, guint msb, GError **error)
+arv_gc_register_node_get_masked_integer_value (ArvGcRegisterNode *gc_register_node,
+					       guint lsb, guint msb, ArvGcSignedness signedness,
+					       GError **error)
 {
 	g_return_val_if_fail (ARV_IS_GC_REGISTER_NODE (gc_register_node), 0);
 	g_return_val_if_fail (error == NULL || *error == NULL, 0);
 
-	return _get_integer_value (gc_register_node, lsb, msb, error);
+	return _get_integer_value (gc_register_node, lsb, msb, signedness, error);
 }
 
 static gint64
@@ -748,6 +788,7 @@ arv_gc_register_node_get_integer_value (ArvGcInteger *gc_integer, GError **error
 {
 	GError *local_error = NULL;
 	ArvGcRegisterNode *gc_register_node = ARV_GC_REGISTER_NODE (gc_integer);
+	ArvGcSignedness signedness;
 	gint64 lsb, msb;
 
 	lsb = _get_lsb (gc_register_node, &local_error);
@@ -764,7 +805,14 @@ arv_gc_register_node_get_integer_value (ArvGcInteger *gc_integer, GError **error
 		return 0;
 	}
 
-	return _get_integer_value (gc_register_node, lsb, msb, error);
+	signedness = _get_signedness (gc_register_node, &local_error);
+
+	if (local_error != NULL) {
+		g_propagate_error (error, local_error);
+		return 0;
+	}
+
+	return _get_integer_value (gc_register_node, lsb, msb, signedness, error);
 }
 
 static void
@@ -805,9 +853,9 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node, guint register_lsb, gui
 			msb = 8 * gc_register_node->cache_size - register_msb - 1;
 		}
 
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
+		arv_log_genicam ("[GcRegisterNode::_set_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
 				 register_lsb, register_msb, lsb, msb);
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] value = 0x%08Lx", value);
+		arv_log_genicam ("[GcRegisterNode::_set_integer_value] value = 0x%08Lx", value);
 
 		if (msb - lsb < 63)
 			mask = ((((guint64) 1) << (msb - lsb + 1)) - 1) << lsb;
@@ -816,7 +864,14 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node, guint register_lsb, gui
 
 		value = ((value << lsb) & mask) | (current_value & ~mask);
 
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] mask  = 0x%08Lx", mask);
+		arv_log_genicam ("[GcRegisterNode::_set_integer_value] mask  = 0x%08Lx", mask);
+	} else {
+		_update_cache_size (gc_register_node, &local_error);
+
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return;
+		}
 	}
 
 	arv_log_genicam ("[GcRegisterNode::_set_integer_value] address = 0x%Lx, value = 0x%Lx",
